@@ -1,6 +1,5 @@
 from sqlite3 import DataError
 import traceback
-import numpy as np
 import httpx
 from aiohttp_retry import ExponentialRetry, RetryClient
 
@@ -9,7 +8,6 @@ from qiniu import BucketManager, build_batch_delete
 from qiniu import Zone, set_default
 
 from hamunafs.backends.base import BackendBase
-from aiofile import AIOFile, Writer
 
 class Qiniu(BackendBase):
     def __init__(self, cfg):
@@ -48,19 +46,7 @@ class Qiniu(BackendBase):
             return False, str(e)
     
     async def put_async(self, file, bucket, bucket_name, tmp=True):
-        try:
-            if tmp:
-                _bucket = 'tmp_file_' + bucket
-            else:
-                _bucket = bucket
-            b_name = '{}_{}'.format(_bucket, bucket_name)
-            bucket = self.cow.get_bucket(self.default_bucket)
-            ret, info = await bucket.put_file(key=b_name, file_path=file)
-            if info.status_code == 200:
-                return True, '{}/{}'.format(_bucket, bucket_name)
-            return False, '上传失败'
-        except Exception as e:
-            return False, str(e)
+        return self.put(file, bucket, bucket_name, tmp)
 
     def put_buffer(self, buffer, bucket, bucket_name):
         try:
@@ -74,15 +60,7 @@ class Qiniu(BackendBase):
             return False, str(e)
 
     async def put_buffer_async(self, buffer, bucket, bucket_name):
-        try:
-            b_name = '{}_{}'.format(bucket, bucket_name)
-            bucket = await self.cow.get_bucket(self.default_bucket)
-            ret, info = await bucket.put_data(key=b_name, data=buffer)
-            if ret is not None:
-                return True, '{}/{}'.format(bucket, bucket_name)
-            return False, '上传失败'
-        except Exception as e:
-            return False, str(e)
+        return self.put_buffer(buffer, bucket, bucket_name)
 
     def get(self, download_path, bucket, bucket_name, tries=0):
         try:
