@@ -252,6 +252,10 @@ class XRedis(Singleton):
         return conn.zadd(z_name, {
             member: val
         })
+    
+    async def zrem(self, z_name, member):
+        conn = self.__get_connection()
+        return await conn.zrem(z_name, member)
         
     def zrange(self, z_name, score_min, score_max):
         conn = self._get_connection()
@@ -276,7 +280,7 @@ class XRedisAsync(Singleton):
         self.locker = threading.Lock()
 
         # pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, max_connections=4, socket_timeout=60, socket_connect_timeout=30, socket_keepalive=True)
-        pool = coredis.ConnectionPool.from_url('redis://:{}@{}:{}/{}'.format(self.password, self.host, self.port, self.db), decode_components=True)
+        pool = coredis.ConnectionPool.from_url('redis://:{}@{}:{}/{}'.format(self.password, self.host, self.port, self.db), decode_responses=True)
         self.conn = coredis.StrictRedis(connection_pool=pool)
             
     async def __release_conn(self):
@@ -468,9 +472,11 @@ class XRedisAsync(Singleton):
     
     async def zadd(self, z_name, member, val):
         conn = self.__get_connection()
-        return await conn.zadd(z_name, {
-            member: val
-        })
+        return await conn.zadd(z_name, member, val)
+    
+    async def zrem(self, z_name, member):
+        conn = self.__get_connection()
+        return await conn.zrem(z_name, member)
         
     async def zrange(self, z_name, score_min, score_max):
         conn = self.__get_connection()
